@@ -38,13 +38,6 @@ from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.typing_compat import Protocol, runtime_checkable
 
-# Add exceptions to pylint for the boto3 protocol only; ideally the boto3 library
-# could provide
-# protocols for all their dynamically generated classes (try to migrate this to a PR on botocore).
-# Note that the use of invalid-name parameters should be restricted to the boto3 mappings only;
-# all the Airflow wrappers of boto3 clients should not adopt invalid-names to match boto3.
-# pylint: disable=invalid-name, unused-argument
-
 
 @runtime_checkable
 class AwsBatchProtocol(Protocol):
@@ -156,7 +149,6 @@ class AwsBatchProtocol(Protocol):
 
 # Note that the use of invalid-name parameters should be restricted to the boto3 mappings only;
 # all the Airflow wrappers of boto3 clients should not adopt invalid-names to match boto3.
-# pylint: enable=invalid-name, unused-argument
 
 
 class AwsBatchClientHook(AwsBaseHook):
@@ -212,9 +204,9 @@ class AwsBatchClientHook(AwsBaseHook):
         self.status_retries = status_retries or self.STATUS_RETRIES
 
     @property
-    def client(self) -> Union[AwsBatchProtocol, botocore.client.BaseClient]:  # noqa: D402
+    def client(self) -> Union[AwsBatchProtocol, botocore.client.BaseClient]:
         """
-        An AWS API client for batch services, like ``boto3.client('batch')``
+        An AWS API client for batch services.
 
         :return: a boto3 'batch' client for the ``.region_name``
         :rtype: Union[AwsBatchProtocol, botocore.client.BaseClient]
@@ -398,8 +390,8 @@ class AwsBatchClientHook(AwsBaseHook):
             retries += 1
             if retries >= self.status_retries:
                 raise AirflowException(
-                    "AWS Batch job ({}) description error: exceeded "
-                    "status_retries ({})".format(job_id, self.status_retries)
+                    f"AWS Batch job ({job_id}) description error: exceeded status_retries "
+                    f"({self.status_retries})"
                 )
 
             pause = self.exponential_delay(retries)
