@@ -21,12 +21,11 @@ import logging
 import random
 from typing import List, Optional
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowTaskTimeout
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.datasync import AWSDataSyncHook
 
 
-# pylint: disable=too-many-instance-attributes, too-many-arguments
 class AWSDataSyncOperator(BaseOperator):
     r"""Find, Create, Update, Execute and Delete AWS DataSync Tasks.
 
@@ -46,6 +45,9 @@ class AWSDataSyncOperator(BaseOperator):
     :param wait_interval_seconds: Time to wait between two
         consecutive calls to check TaskExecution status.
     :type wait_interval_seconds: int
+    :param max_iterations: Maximum number of
+        consecutive calls to check TaskExecution status.
+    :type max_iterations: int
     :param task_arn: AWS DataSync TaskArn to use. If None, then this operator will
         attempt to either search for an existing Task or attempt to create a new Task.
     :type task_arn: str
@@ -116,11 +118,11 @@ class AWSDataSyncOperator(BaseOperator):
         "task_execution_kwargs",
     )
     template_fields_renderers = {
-        "create_task_kwargs": "py",
-        "create_source_location_kwargs": "py",
-        "create_destination_location_kwargs": "py",
-        "update_task_kwargs": "py",
-        "task_execution_kwargs": "py",
+        "create_task_kwargs": "json",
+        "create_source_location_kwargs": "json",
+        "create_destination_location_kwargs": "json",
+        "update_task_kwargs": "json",
+        "task_execution_kwargs": "json",
     }
     ui_color = "#44b5e2"
 
@@ -128,7 +130,8 @@ class AWSDataSyncOperator(BaseOperator):
         self,
         *,
         aws_conn_id: str = "aws_default",
-        wait_interval_seconds: int = 5,
+        wait_interval_seconds: int = 30,
+        max_iterations: int = 60,
         task_arn: Optional[str] = None,
         source_location_uri: Optional[str] = None,
         destination_location_uri: Optional[str] = None,
@@ -147,6 +150,7 @@ class AWSDataSyncOperator(BaseOperator):
         # Assignments
         self.aws_conn_id = aws_conn_id
         self.wait_interval_seconds = wait_interval_seconds
+        self.max_iterations = max_iterations
 
         self.task_arn = task_arn
 
@@ -175,10 +179,9 @@ class AWSDataSyncOperator(BaseOperator):
             valid = True
         if not valid:
             raise AirflowException(
-                "Either specify task_arn or both source_location_uri and destination_location_uri. "
-                "task_arn={} source_location_uri={} destination_location_uri={}".format(
-                    task_arn, source_location_uri, destination_location_uri
-                )
+                f"Either specify task_arn or both source_location_uri and destination_location_uri. "
+                f"task_arn={task_arn!r}, source_location_uri={source_location_uri!r}, "
+                f"destination_location_uri={destination_location_uri!r}"
             )
 
         # Others
@@ -355,8 +358,14 @@ class AWSDataSyncOperator(BaseOperator):
 
         # Wait for task execution to complete
         self.log.info("Waiting for TaskExecutionArn %s", self.task_execution_arn)
-        result = hook.wait_for_task_execution(self.task_execution_arn)
+        try:
+            result = hook.wait_for_task_execution(self.task_execution_arn, max_iterations=self.max_iterations)
+        except (AirflowTaskTimeout, AirflowException) as e:
+            self.log.error('Cancelling TaskExecution after Exception: %s', e)
+            self._cancel_datasync_task_execution()
+            raise
         self.log.info("Completed TaskExecutionArn %s", self.task_execution_arn)
+
         task_execution_description = hook.describe_task_execution(task_execution_arn=self.task_execution_arn)
         self.log.info("task_execution_description=%s", task_execution_description)
 
@@ -371,7 +380,7 @@ class AWSDataSyncOperator(BaseOperator):
         if not result:
             raise AirflowException(f"Failed TaskExecutionArn {self.task_execution_arn}")
 
-    def on_kill(self) -> None:
+    def _cancel_datasync_task_execution(self):
         """Cancel the submitted DataSync task."""
         hook = self.get_hook()
         if self.task_execution_arn:
@@ -379,6 +388,10 @@ class AWSDataSyncOperator(BaseOperator):
             hook.cancel_task_execution(task_execution_arn=self.task_execution_arn)
             self.log.info("Cancelled TaskExecutionArn %s", self.task_execution_arn)
 
+    def on_kill(self):
+        self.log.error('Cancelling TaskExecution after task was killed')
+        self._cancel_datasync_task_execution()
+
     def _delete_datasync_task(self) -> None:
         """Deletes an AWS DataSync Task."""
         if not self.task_arn:
