@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.sensors.base import BaseSensorOperator
@@ -23,9 +23,9 @@ from airflow.sensors.base import BaseSensorOperator
 
 class S3PrefixSensor(BaseSensorOperator):
     """
-    Waits for a prefix to exist. A prefix is the first part of a key,
-    thus enabling checking of constructs similar to glob airfl* or
-    SQL LIKE 'airfl%'. There is the possibility to precise a delimiter to
+    Waits for a prefix or all prefixes to exist. A prefix is the first part of a key,
+    thus enabling checking of constructs similar to glob ``airfl*`` or
+    SQL LIKE ``'airfl%'``. There is the possibility to precise a delimiter to
     indicate the hierarchy or keys, meaning that the match will stop at that
     delimiter. Current code accepts sane delimiters, i.e. characters that
     are NOT special characters in the Python regex engine.
@@ -33,7 +33,7 @@ class S3PrefixSensor(BaseSensorOperator):
     :param bucket_name: Name of the S3 bucket
     :type bucket_name: str
     :param prefix: The prefix being waited on. Relative path from bucket root level.
-    :type prefix: str
+    :type prefix: str or list of str
     :param delimiter: The delimiter intended to show hierarchy.
         Defaults to '/'.
     :type delimiter: str
@@ -58,7 +58,7 @@ class S3PrefixSensor(BaseSensorOperator):
         self,
         *,
         bucket_name: str,
-        prefix: str,
+        prefix: Union[str, List[str]],
         delimiter: str = '/',
         aws_conn_id: str = 'aws_default',
         verify: Optional[Union[str, bool]] = None,
@@ -67,18 +67,15 @@ class S3PrefixSensor(BaseSensorOperator):
         super().__init__(**kwargs)
         # Parse
         self.bucket_name = bucket_name
-        self.prefix = prefix
+        self.prefix = [prefix] if isinstance(prefix, str) else prefix
         self.delimiter = delimiter
-        self.full_url = "s3://" + bucket_name + '/' + prefix
         self.aws_conn_id = aws_conn_id
         self.verify = verify
         self.hook: Optional[S3Hook] = None
 
-    def poke(self, context):
+    def poke(self, context: Dict[str, Any]):
         self.log.info('Poking for prefix : %s in bucket s3://%s', self.prefix, self.bucket_name)
-        return self.get_hook().check_for_prefix(
-            prefix=self.prefix, delimiter=self.delimiter, bucket_name=self.bucket_name
-        )
+        return all(self._check_for_prefix(prefix) for prefix in self.prefix)
 
     def get_hook(self) -> S3Hook:
         """Create and return an S3Hook"""
@@ -87,3 +84,8 @@ class S3PrefixSensor(BaseSensorOperator):
 
         self.hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
         return self.hook
+
+    def _check_for_prefix(self, prefix: str) -> bool:
+        return self.get_hook().check_for_prefix(
+            prefix=prefix, delimiter=self.delimiter, bucket_name=self.bucket_name
+        )
